

-- UUAGC 0.9.37.1 (DeclBlocks.ag)
module DeclBlocks where
{-# LINE 2 "DeclBlocks.ag" #-}

import Code (Decl,Expr)
{-# LINE 9 "../src-derived/DeclBlocks.hs" #-}
-- DeclBlocks --------------------------------------------------
{-
   alternatives:
      alternative DeclBlock:
         child defs           : {[Decl]}
         child visit          : {Decl}
         child next           : DeclBlocks 
      alternative DeclTerminator:
         child defs           : {[Decl]}
         child result         : {Expr}
-}
data DeclBlocks  = DeclBlock (([Decl])) (Decl) (DeclBlocks ) 
                 | DeclTerminator (([Decl])) (Expr) 
-- DeclBlocksRoot ----------------------------------------------
{-
   alternatives:
      alternative DeclBlocksRoot:
         child blocks         : DeclBlocks 
-}
data DeclBlocksRoot  = DeclBlocksRoot (DeclBlocks ) 